from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.0.1'
DESCRIPTION = "WORD BUILDEr"
LONG_DESCRIPTION = "ITS A FUCKING WORD BUILDER WHY DO I AVE TO EXPLAIN TWICE"

#setting up
setup(
    name = "Wordbuilds",
    version = VERSION,
    author = "Moses",
    author_email = "urmom.youthought@gmail.com",
    description = DESCRIPTION,
    long_description_content_type = "text/markdown",
    long_description = LONG_DESCRIPTION,
    packages= find_packages(),
    install_requires = [],
    keywords = ["Beginner.py", "Rick Roll", "Build a bear", "Lmao"],
    classifiers = [
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",  
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)

     








